@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import DatasetTypeType, DomainType
 from .paginator import (
@@ -28,37 +28,37 @@ from .paginator import (
     ListPredictorsPaginator,
 )
 from .type_defs import (
-    CreateDatasetGroupResponseResponseTypeDef,
-    CreateDatasetImportJobResponseResponseTypeDef,
-    CreateDatasetResponseResponseTypeDef,
-    CreateForecastExportJobResponseResponseTypeDef,
-    CreateForecastResponseResponseTypeDef,
-    CreatePredictorBacktestExportJobResponseResponseTypeDef,
-    CreatePredictorResponseResponseTypeDef,
+    CreateDatasetGroupResponseTypeDef,
+    CreateDatasetImportJobResponseTypeDef,
+    CreateDatasetResponseTypeDef,
+    CreateForecastExportJobResponseTypeDef,
+    CreateForecastResponseTypeDef,
+    CreatePredictorBacktestExportJobResponseTypeDef,
+    CreatePredictorResponseTypeDef,
     DataDestinationTypeDef,
     DataSourceTypeDef,
-    DescribeDatasetGroupResponseResponseTypeDef,
-    DescribeDatasetImportJobResponseResponseTypeDef,
-    DescribeDatasetResponseResponseTypeDef,
-    DescribeForecastExportJobResponseResponseTypeDef,
-    DescribeForecastResponseResponseTypeDef,
-    DescribePredictorBacktestExportJobResponseResponseTypeDef,
-    DescribePredictorResponseResponseTypeDef,
+    DescribeDatasetGroupResponseTypeDef,
+    DescribeDatasetImportJobResponseTypeDef,
+    DescribeDatasetResponseTypeDef,
+    DescribeForecastExportJobResponseTypeDef,
+    DescribeForecastResponseTypeDef,
+    DescribePredictorBacktestExportJobResponseTypeDef,
+    DescribePredictorResponseTypeDef,
     EncryptionConfigTypeDef,
     EvaluationParametersTypeDef,
     FeaturizationConfigTypeDef,
     FilterTypeDef,
-    GetAccuracyMetricsResponseResponseTypeDef,
+    GetAccuracyMetricsResponseTypeDef,
     HyperParameterTuningJobConfigTypeDef,
     InputDataConfigTypeDef,
-    ListDatasetGroupsResponseResponseTypeDef,
-    ListDatasetImportJobsResponseResponseTypeDef,
-    ListDatasetsResponseResponseTypeDef,
-    ListForecastExportJobsResponseResponseTypeDef,
-    ListForecastsResponseResponseTypeDef,
-    ListPredictorBacktestExportJobsResponseResponseTypeDef,
-    ListPredictorsResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
+    ListDatasetGroupsResponseTypeDef,
+    ListDatasetImportJobsResponseTypeDef,
+    ListDatasetsResponseTypeDef,
+    ListForecastExportJobsResponseTypeDef,
+    ListForecastsResponseTypeDef,
+    ListPredictorBacktestExportJobsResponseTypeDef,
+    ListPredictorsResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
     SchemaTypeDef,
     TagTypeDef,
 )
@@ -90,20 +90,25 @@ class Exceptions:
     ResourceNotFoundException: Type[BotocoreClientError]
 
 
-class ForecastServiceClient:
+class ForecastServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        ForecastServiceClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#can_paginate)
         """
 
@@ -117,11 +122,11 @@ class ForecastServiceClient:
         DataFrequency: str = None,
         EncryptionConfig: "EncryptionConfigTypeDef" = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateDatasetResponseResponseTypeDef:
+    ) -> CreateDatasetResponseTypeDef:
         """
         Creates an Amazon Forecast dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.create_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.create_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_dataset)
         """
 
@@ -132,11 +137,11 @@ class ForecastServiceClient:
         Domain: DomainType,
         DatasetArns: List[str] = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateDatasetGroupResponseResponseTypeDef:
+    ) -> CreateDatasetGroupResponseTypeDef:
         """
         Creates a dataset group, which holds a collection of related datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.create_dataset_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.create_dataset_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_dataset_group)
         """
 
@@ -151,11 +156,11 @@ class ForecastServiceClient:
         UseGeolocationForTimeZone: bool = None,
         GeolocationFormat: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateDatasetImportJobResponseResponseTypeDef:
+    ) -> CreateDatasetImportJobResponseTypeDef:
         """
         Imports your training data to an Amazon Forecast dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.create_dataset_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.create_dataset_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_dataset_import_job)
         """
 
@@ -166,12 +171,12 @@ class ForecastServiceClient:
         PredictorArn: str,
         ForecastTypes: List[str] = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateForecastResponseResponseTypeDef:
+    ) -> CreateForecastResponseTypeDef:
         """
         Creates a forecast for each item in the `TARGET_TIME_SERIES` dataset that was
         used to train the predictor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.create_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.create_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_forecast)
         """
 
@@ -182,12 +187,12 @@ class ForecastServiceClient:
         ForecastArn: str,
         Destination: "DataDestinationTypeDef",
         Tags: List["TagTypeDef"] = None
-    ) -> CreateForecastExportJobResponseResponseTypeDef:
+    ) -> CreateForecastExportJobResponseTypeDef:
         """
         Exports a forecast created by the  CreateForecast operation to your Amazon
         Simple Storage Service (Amazon S3) bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.create_forecast_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.create_forecast_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_forecast_export_job)
         """
 
@@ -208,11 +213,11 @@ class ForecastServiceClient:
         HPOConfig: "HyperParameterTuningJobConfigTypeDef" = None,
         EncryptionConfig: "EncryptionConfigTypeDef" = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreatePredictorResponseResponseTypeDef:
+    ) -> CreatePredictorResponseTypeDef:
         """
         Creates an Amazon Forecast predictor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.create_predictor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.create_predictor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_predictor)
         """
 
@@ -223,12 +228,12 @@ class ForecastServiceClient:
         PredictorArn: str,
         Destination: "DataDestinationTypeDef",
         Tags: List["TagTypeDef"] = None
-    ) -> CreatePredictorBacktestExportJobResponseResponseTypeDef:
+    ) -> CreatePredictorBacktestExportJobResponseTypeDef:
         """
         Exports backtest forecasts and accuracy metrics generated by the
         CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.create_predictor_backtest_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.create_predictor_backtest_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#create_predictor_backtest_export_job)
         """
 
@@ -237,7 +242,7 @@ class ForecastServiceClient:
         Deletes an Amazon Forecast dataset that was created using the  CreateDataset
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_dataset)
         """
 
@@ -245,7 +250,7 @@ class ForecastServiceClient:
         """
         Deletes a dataset group created using the  CreateDatasetGroup operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.delete_dataset_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.delete_dataset_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_dataset_group)
         """
 
@@ -254,7 +259,7 @@ class ForecastServiceClient:
         Deletes a dataset import job created using the  CreateDatasetImportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.delete_dataset_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.delete_dataset_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_dataset_import_job)
         """
 
@@ -262,7 +267,7 @@ class ForecastServiceClient:
         """
         Deletes a forecast created using the  CreateForecast operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.delete_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.delete_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_forecast)
         """
 
@@ -271,7 +276,7 @@ class ForecastServiceClient:
         Deletes a forecast export job created using the  CreateForecastExportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.delete_forecast_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.delete_forecast_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_forecast_export_job)
         """
 
@@ -279,7 +284,7 @@ class ForecastServiceClient:
         """
         Deletes a predictor created using the  CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.delete_predictor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.delete_predictor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_predictor)
         """
 
@@ -287,7 +292,7 @@ class ForecastServiceClient:
         """
         Deletes a predictor backtest export job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.delete_predictor_backtest_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.delete_predictor_backtest_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_predictor_backtest_export_job)
         """
 
@@ -295,74 +300,74 @@ class ForecastServiceClient:
         """
         Deletes an entire resource tree.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.delete_resource_tree)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.delete_resource_tree)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#delete_resource_tree)
         """
 
-    def describe_dataset(self, *, DatasetArn: str) -> DescribeDatasetResponseResponseTypeDef:
+    def describe_dataset(self, *, DatasetArn: str) -> DescribeDatasetResponseTypeDef:
         """
         Describes an Amazon Forecast dataset created using the  CreateDataset operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.describe_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_dataset)
         """
 
     def describe_dataset_group(
         self, *, DatasetGroupArn: str
-    ) -> DescribeDatasetGroupResponseResponseTypeDef:
+    ) -> DescribeDatasetGroupResponseTypeDef:
         """
         Describes a dataset group created using the  CreateDatasetGroup operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.describe_dataset_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.describe_dataset_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_dataset_group)
         """
 
     def describe_dataset_import_job(
         self, *, DatasetImportJobArn: str
-    ) -> DescribeDatasetImportJobResponseResponseTypeDef:
+    ) -> DescribeDatasetImportJobResponseTypeDef:
         """
         Describes a dataset import job created using the  CreateDatasetImportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.describe_dataset_import_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.describe_dataset_import_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_dataset_import_job)
         """
 
-    def describe_forecast(self, *, ForecastArn: str) -> DescribeForecastResponseResponseTypeDef:
+    def describe_forecast(self, *, ForecastArn: str) -> DescribeForecastResponseTypeDef:
         """
         Describes a forecast created using the  CreateForecast operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.describe_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.describe_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_forecast)
         """
 
     def describe_forecast_export_job(
         self, *, ForecastExportJobArn: str
-    ) -> DescribeForecastExportJobResponseResponseTypeDef:
+    ) -> DescribeForecastExportJobResponseTypeDef:
         """
         Describes a forecast export job created using the  CreateForecastExportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.describe_forecast_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.describe_forecast_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_forecast_export_job)
         """
 
-    def describe_predictor(self, *, PredictorArn: str) -> DescribePredictorResponseResponseTypeDef:
+    def describe_predictor(self, *, PredictorArn: str) -> DescribePredictorResponseTypeDef:
         """
         Describes a predictor created using the  CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.describe_predictor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.describe_predictor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_predictor)
         """
 
     def describe_predictor_backtest_export_job(
         self, *, PredictorBacktestExportJobArn: str
-    ) -> DescribePredictorBacktestExportJobResponseResponseTypeDef:
+    ) -> DescribePredictorBacktestExportJobResponseTypeDef:
         """
         Describes a predictor backtest export job created using the
         CreatePredictorBacktestExportJob operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.describe_predictor_backtest_export_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.describe_predictor_backtest_export_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#describe_predictor_backtest_export_job)
         """
 
@@ -376,29 +381,27 @@ class ForecastServiceClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#generate_presigned_url)
         """
 
-    def get_accuracy_metrics(
-        self, *, PredictorArn: str
-    ) -> GetAccuracyMetricsResponseResponseTypeDef:
+    def get_accuracy_metrics(self, *, PredictorArn: str) -> GetAccuracyMetricsResponseTypeDef:
         """
         Provides metrics on the accuracy of the models that were trained by the
         CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.get_accuracy_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.get_accuracy_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#get_accuracy_metrics)
         """
 
     def list_dataset_groups(
         self, *, NextToken: str = None, MaxResults: int = None
-    ) -> ListDatasetGroupsResponseResponseTypeDef:
+    ) -> ListDatasetGroupsResponseTypeDef:
         """
         Returns a list of dataset groups created using the  CreateDatasetGroup
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.list_dataset_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.list_dataset_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_dataset_groups)
         """
 
@@ -408,22 +411,22 @@ class ForecastServiceClient:
         NextToken: str = None,
         MaxResults: int = None,
         Filters: List["FilterTypeDef"] = None
-    ) -> ListDatasetImportJobsResponseResponseTypeDef:
+    ) -> ListDatasetImportJobsResponseTypeDef:
         """
         Returns a list of dataset import jobs created using the  CreateDatasetImportJob
         operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.list_dataset_import_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.list_dataset_import_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_dataset_import_jobs)
         """
 
     def list_datasets(
         self, *, NextToken: str = None, MaxResults: int = None
-    ) -> ListDatasetsResponseResponseTypeDef:
+    ) -> ListDatasetsResponseTypeDef:
         """
         Returns a list of datasets created using the  CreateDataset operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_datasets)
         """
 
@@ -433,12 +436,12 @@ class ForecastServiceClient:
         NextToken: str = None,
         MaxResults: int = None,
         Filters: List["FilterTypeDef"] = None
-    ) -> ListForecastExportJobsResponseResponseTypeDef:
+    ) -> ListForecastExportJobsResponseTypeDef:
         """
         Returns a list of forecast export jobs created using the
         CreateForecastExportJob operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.list_forecast_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.list_forecast_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_forecast_export_jobs)
         """
 
@@ -448,11 +451,11 @@ class ForecastServiceClient:
         NextToken: str = None,
         MaxResults: int = None,
         Filters: List["FilterTypeDef"] = None
-    ) -> ListForecastsResponseResponseTypeDef:
+    ) -> ListForecastsResponseTypeDef:
         """
         Returns a list of forecasts created using the  CreateForecast operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.list_forecasts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.list_forecasts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_forecasts)
         """
 
@@ -462,12 +465,12 @@ class ForecastServiceClient:
         NextToken: str = None,
         MaxResults: int = None,
         Filters: List["FilterTypeDef"] = None
-    ) -> ListPredictorBacktestExportJobsResponseResponseTypeDef:
+    ) -> ListPredictorBacktestExportJobsResponseTypeDef:
         """
         Returns a list of predictor backtest export jobs created using the
         CreatePredictorBacktestExportJob operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.list_predictor_backtest_export_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.list_predictor_backtest_export_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_predictor_backtest_export_jobs)
         """
 
@@ -477,21 +480,19 @@ class ForecastServiceClient:
         NextToken: str = None,
         MaxResults: int = None,
         Filters: List["FilterTypeDef"] = None
-    ) -> ListPredictorsResponseResponseTypeDef:
+    ) -> ListPredictorsResponseTypeDef:
         """
         Returns a list of predictors created using the  CreatePredictor operation.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.list_predictors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.list_predictors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_predictors)
         """
 
-    def list_tags_for_resource(
-        self, *, ResourceArn: str
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags for an Amazon Forecast resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#list_tags_for_resource)
         """
 
@@ -499,7 +500,7 @@ class ForecastServiceClient:
         """
         Stops a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.stop_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.stop_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#stop_resource)
         """
 
@@ -507,7 +508,7 @@ class ForecastServiceClient:
         """
         Associates the specified tags to a resource with the specified `resourceArn`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#tag_resource)
         """
 
@@ -515,7 +516,7 @@ class ForecastServiceClient:
         """
         Deletes the specified tags from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#untag_resource)
         """
 
@@ -525,7 +526,7 @@ class ForecastServiceClient:
         """
         Replaces the datasets in a dataset group with the specified datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Client.update_dataset_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Client.update_dataset_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/client.html#update_dataset_group)
         """
 
@@ -534,7 +535,7 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_dataset_groups"]
     ) -> ListDatasetGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetgroupspaginator)
         """
 
@@ -543,14 +544,14 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_dataset_import_jobs"]
     ) -> ListDatasetImportJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetimportjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetspaginator)
         """
 
@@ -559,14 +560,14 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_forecast_export_jobs"]
     ) -> ListForecastExportJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listforecastexportjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_forecasts"]) -> ListForecastsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listforecastspaginator)
         """
 
@@ -575,13 +576,13 @@ class ForecastServiceClient:
         self, operation_name: Literal["list_predictor_backtest_export_jobs"]
     ) -> ListPredictorBacktestExportJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListPredictorBacktestExportJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListPredictorBacktestExportJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listpredictorbacktestexportjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_predictors"]) -> ListPredictorsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listpredictorspaginator)
         """
