@@ -36,13 +36,13 @@ from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
     FilterTypeDef,
-    ListDatasetGroupsResponseResponseTypeDef,
-    ListDatasetImportJobsResponseResponseTypeDef,
-    ListDatasetsResponseResponseTypeDef,
-    ListForecastExportJobsResponseResponseTypeDef,
-    ListForecastsResponseResponseTypeDef,
-    ListPredictorBacktestExportJobsResponseResponseTypeDef,
-    ListPredictorsResponseResponseTypeDef,
+    ListDatasetGroupsResponseTypeDef,
+    ListDatasetImportJobsResponseTypeDef,
+    ListDatasetsResponseTypeDef,
+    ListForecastExportJobsResponseTypeDef,
+    ListForecastsResponseTypeDef,
+    ListPredictorBacktestExportJobsResponseTypeDef,
+    ListPredictorsResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -59,22 +59,22 @@ __all__ = (
 
 class ListDatasetGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetgroupspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDatasetGroupsResponseResponseTypeDef]:
+    ) -> Iterator[ListDatasetGroupsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListDatasetGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetgroupspaginator)
         """
 
 
 class ListDatasetImportJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetimportjobspaginator)
     """
 
@@ -83,31 +83,31 @@ class ListDatasetImportJobsPaginator(Boto3Paginator):
         *,
         Filters: List["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDatasetImportJobsResponseResponseTypeDef]:
+    ) -> Iterator[ListDatasetImportJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListDatasetImportJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetimportjobspaginator)
         """
 
 
 class ListDatasetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListDatasets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDatasetsResponseResponseTypeDef]:
+    ) -> Iterator[ListDatasetsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListDatasets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListDatasets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listdatasetspaginator)
         """
 
 
 class ListForecastExportJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listforecastexportjobspaginator)
     """
 
@@ -116,16 +116,16 @@ class ListForecastExportJobsPaginator(Boto3Paginator):
         *,
         Filters: List["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListForecastExportJobsResponseResponseTypeDef]:
+    ) -> Iterator[ListForecastExportJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListForecastExportJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listforecastexportjobspaginator)
         """
 
 
 class ListForecastsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListForecasts)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listforecastspaginator)
     """
 
@@ -134,16 +134,16 @@ class ListForecastsPaginator(Boto3Paginator):
         *,
         Filters: List["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListForecastsResponseResponseTypeDef]:
+    ) -> Iterator[ListForecastsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListForecasts.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListForecasts.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listforecastspaginator)
         """
 
 
 class ListPredictorBacktestExportJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListPredictorBacktestExportJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListPredictorBacktestExportJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listpredictorbacktestexportjobspaginator)
     """
 
@@ -152,16 +152,16 @@ class ListPredictorBacktestExportJobsPaginator(Boto3Paginator):
         *,
         Filters: List["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPredictorBacktestExportJobsResponseResponseTypeDef]:
+    ) -> Iterator[ListPredictorBacktestExportJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListPredictorBacktestExportJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListPredictorBacktestExportJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listpredictorbacktestexportjobspaginator)
         """
 
 
 class ListPredictorsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListPredictors)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listpredictorspaginator)
     """
 
@@ -170,8 +170,8 @@ class ListPredictorsPaginator(Boto3Paginator):
         *,
         Filters: List["FilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPredictorsResponseResponseTypeDef]:
+    ) -> Iterator[ListPredictorsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/forecast.html#ForecastService.Paginator.ListPredictors.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.108/reference/services/forecast.html#ForecastService.Paginator.ListPredictors.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/paginators.html#listpredictorspaginator)
         """
